//////////////////////////////////////////////////////////////////////////////
//
//  Copyright 2009 ITmedia Inc. All right reserved.
//
//////////////////////////////////////////////////////////////////////////////
package jp.co.atmarkit.sample.dao {
import flash.events.EventDispatcher;

import jp.co.atmarkit.sample.dto.UserRequestDto;
import jp.co.atmarkit.sample.dto.UserResponseDto;
import jp.co.atmarkit.sample.entity.User;
import jp.co.atmarkit.sample.utils.DebugUtil;

import mx.rpc.events.ResultEvent;


/**
 * ユーザー情報を取得するためのDAOです。
 */
public class UserDao extends EventDispatcher {

//--------------------------------------
//  Variables
//--------------------------------------
    
    /** XML形式のユーザー一覧データです。 */
    private var users:XML;

    [Embed(source="repository/data/users.xml", mimeType="application/octet-stream")]
    /** XML形式のユーザー一覧データです。 */
    private var embedUsers:Class;

//--------------------------------------
//  Functions
//--------------------------------------

    /**
     * ユーザー一覧を取得します。
     * ※実際はこのクラスを経由してサーバーからユーザー一覧を取得します。
     * 
     * @param dto リクエストDTOです。
     */
    public function getUserList(dto:UserRequestDto):void {
        DebugUtil.debug("UserDao#getUserList");
        // サーバーにアクセスしたと仮定して、結果イベントを直接呼び出します。
        getUserListResultHandler(new ResultEvent(ResultEvent.RESULT));
    }
    
    /**
     * ユーザー一覧取得の結果イベントハンドラです。
     */
    private function getUserListResultHandler(event:ResultEvent):void {
        DebugUtil.debug("UserDao#getUserListResultHandler");
        
        // ユーザー一覧が取得できたと仮定して、結果を保持するレスポンスDTOを作成します。
        var responseDto:UserResponseDto = new UserResponseDto();
        
        // XMLからユーザー一覧を生成し、レスポンスDTOにセットします。
        responseDto.userList = createUserListFromXML();

        var myEvent:ResultEvent = new ResultEvent(ResultEvent.RESULT, false, true, responseDto);
        
        dispatchEvent(myEvent);
    }
    
    /**
     * XMLからユーザー一覧を作成します。
     * 
     * @return ユーザー一覧です。
     */
    private function createUserListFromXML():Array {
        // XMLを取得します。
        // 変数名はXMLのルートタグと同じにしよう！
        users = new XML(new embedUsers());
        
        var resultValue:Array = new Array();
        var user:XML;
        
        // XMLの配列をオブジェクトの配列に変換します。
        for each(user in users.user) {
            resultValue.push(User.populate(user));
        }
        
        return resultValue;
    }
}
}