//////////////////////////////////////////////////////////////////////////////
//
//  Copyright 2009 ITmedia Inc. All right reserved.
//
//////////////////////////////////////////////////////////////////////////////
package jp.co.atmarkit.sample.web.helper {
import jp.co.atmarkit.sample.dao.UserDao;
import jp.co.atmarkit.sample.dto.UserRequestDto;
import jp.co.atmarkit.sample.dto.UserResponseDto;
import jp.co.atmarkit.sample.entity.User;
import jp.co.atmarkit.sample.helper.ViewHelper;
import jp.co.atmarkit.sample.utils.DebugUtil;
import jp.co.atmarkit.sample.web.Sample;

import mx.events.FlexEvent;
import mx.events.ListEvent;
import mx.rpc.events.ResultEvent;


/**
 * サンプルアプリケーションのヘルパークラスです。
 */
public class SampleViewHelper extends ViewHelper {
    
    /** ユーザーDAOです。 */
    private var dao:UserDao;
    
    /**
     * 初期化完了イベントハンドラです。
     */
    override protected function creationCompleteHandler(event:FlexEvent):void {
        // ユーザー一覧データグリッドの行選択変更イベントハンドラを指定します。
        view.userListDataGrid.addEventListener(ListEvent.ITEM_CLICK, userListDataGridItemClickHandler);

        // ユーザー一覧を取得します。
        getUserList();
    }
    
    /**
     * ユーザー一覧を取得します。
     */
    private function getUserList():void {
        // 空のリクエストDTOを作成します。
        // ユーザー一覧取得には特に取得条件は不要なのでリクエストDTOは空です。
        var dto:UserRequestDto = new UserRequestDto();
        
        // ユーザー一覧を取得します。
        dao = new UserDao();
        dao.addEventListener(ResultEvent.RESULT, getUserListResultHandler);
        dao.getUserList(dto);
    }
    
    /**
     * ユーザー一覧取得の結果イベントです。
     */
    private function getUserListResultHandler(event:ResultEvent):void {
        DebugUtil.debug("SampleViewHelper#getUserListResultHandler");
        
        // レスポンスDTOからユーザー一覧を取得します。
        var dto:UserResponseDto = event.result as UserResponseDto;
        
        // ユーザー一覧を画面のユーザー一覧に設定します。
        view.userListDataGrid.dataProvider = dto.userList;
        
        // Silverlightと挙動を同じにするために、ユーザー一覧の1行目を選択しておきます。
        view.userListDataGrid.selectedIndex = 0;
        
        // Silverlightと挙動を同じにするために、ユーザー一覧の1行目の詳細を表示しておきます。
        var selectedUser:User = view.userListDataGrid.selectedItem as User;
        
        view.nameFormItem.text = selectedUser.name;
        view.addressFormItem.text = selectedUser.address;
        view.ageFormItem.text = selectedUser.age;
        view.sexFormItem.text = selectedUser.sex;
    }
    
    /**
     * ユーザー一覧データグリッドの行選択変更イベントハンドラです。
     * 
     * @param event ListEventオブジェクトです。
     */
    private function userListDataGridItemClickHandler(event:ListEvent):void {
        var selectedUser:User = view.userListDataGrid.selectedItem as User;
        
        view.nameFormItem.text = selectedUser.name;
        view.addressFormItem.text = selectedUser.address;
        view.ageFormItem.text = selectedUser.age;
        view.sexFormItem.text = selectedUser.sex;
    }

//--------------------------------------
//  View-Logic Binding
//--------------------------------------

    /** 画面です。 */
    public var _view:Sample;
    
    /**
     * 画面を取得します。
     * 
     * @return 画面です。
     */     
    public function get view():Sample {
        if (_view == null) {
            _view = super.document as Sample;
        }
        
        return _view;
    }
    
    /**
     * 画面をセットします。
     * 
     * @param view セットする画面です。
     */
    public function set view(view:Sample):void {
        _view = view;
    }
}
}